@@ -19,15 +19,13 @@ object supporting an execute() method that does the
 actual HTTP request.
 """
 from __future__ import absolute_import
-import six
 
 __author__ = "jcgregorio@google.com (Joe Gregorio)"
 
-from six import BytesIO, StringIO
-from six.moves.urllib.parse import urlparse, urlunparse, quote, unquote
-
 import copy
 import httplib2
+import http.client as http_client
+import io
 import json
 import logging
 import mimetypes
@@ -35,6 +33,7 @@ import os
 import random
 import socket
 import time
+import urllib
 import uuid
 
 # TODO(issue 221): Remove this conditional import jibbajabba.
@@ -76,11 +75,6 @@ DEFAULT_HTTP_TIMEOUT_SEC = 60
 
 _LEGACY_BATCH_URI = "https://www.googleapis.com/batch"
 
-if six.PY2:
-    # That's a builtin python3 exception, nonexistent in python2.
-    # Defined to None to avoid NameError while trying to catch it
-    ConnectionError = None
-
 
 def _should_retry_response(resp_status, content):
     """Determines whether a response should be retried.
@@ -104,7 +98,7 @@ def _should_retry_response(resp_status, content):
 
     # For 403 errors, we have to check for the `reason` in the response to
     # determine if we should retry.
-    if resp_status == six.moves.http_client.FORBIDDEN:
+    if resp_status == http_client.FORBIDDEN:
         # If there's no details about the 403 type, don't retry.
         if not content:
             return False
@@ -175,7 +169,7 @@ def _retry_request(
     resp = None
     content = None
     exception = None
-    for retry_num in six.moves.range(num_retries + 1):
+    for retry_num in range(num_retries + 1):
         if retry_num > 0:
             # Sleep before retrying.
             sleep_time = rand() * 2 ** retry_num
@@ -634,7 +628,7 @@ class MediaFileUpload(MediaIoBaseUpload):
 class MediaInMemoryUpload(MediaIoBaseUpload):
     """MediaUpload for a chunk of bytes.
 
-    DEPRECATED: Use MediaIoBaseUpload with either io.TextIOBase or StringIO for
+    DEPRECATED: Use MediaIoBaseUpload with either io.TextIOBase or io.StringIO for
     the stream.
     """
 
@@ -648,7 +642,7 @@ class MediaInMemoryUpload(MediaIoBaseUpload):
     ):
         """Create a new MediaInMemoryUpload.
 
-        DEPRECATED: Use MediaIoBaseUpload with either io.TextIOBase or StringIO for
+        DEPRECATED: Use MediaIoBaseUpload with either io.TextIOBase or io.StringIO for
         the stream.
 
         Args:
@@ -660,7 +654,7 @@ class MediaInMemoryUpload(MediaIoBaseUpload):
           resumable: bool, True if this is a resumable upload. False means upload
             in a single request.
         """
-        fd = BytesIO(body)
+        fd = io.BytesIO(body)
         super(MediaInMemoryUpload, self).__init__(
             fd, mimetype, chunksize=chunksize, resumable=resumable
         )
@@ -710,7 +704,7 @@ class MediaIoBaseDownload(object):
         self._rand = random.random
 
         self._headers = {}
-        for k, v in six.iteritems(request.headers):
+        for k, v in request.headers.items():
             # allow users to supply custom headers by setting them on the request
             # but strip out the ones that are set by default on requests generated by
             # API methods like Drive's files().get(fileId=...)
@@ -917,8 +911,8 @@ class HttpRequest(object):
             self.method = "POST"
             self.headers["x-http-method-override"] = "GET"
             self.headers["content-type"] = "application/x-www-form-urlencoded"
-            parsed = urlparse(self.uri)
-            self.uri = urlunparse(
+            parsed = urllib.parse.urlparse(self.uri)
+            self.uri = urllib.parse.urlunparse(
                 (parsed.scheme, parsed.netloc, parsed.path, parsed.params, None, None)
             )
             self.body = parsed.query
@@ -1077,7 +1071,7 @@ class HttpRequest(object):
                 size,
             )
 
-        for retry_num in six.moves.range(num_retries + 1):
+        for retry_num in range(num_retries + 1):
             if retry_num > 0:
                 self._sleep(self._rand() * 2 ** retry_num)
                 LOGGER.warning(
@@ -1298,7 +1292,7 @@ class BatchHttpRequest(object):
         # NB: we intentionally leave whitespace between base/id and '+', so RFC2822
         # line folding works properly on Python 3; see
         # https://github.com/googleapis/google-api-python-client/issues/164
-        return "<%s + %s>" % (self._base_id, quote(id_))
+        return "<%s + %s>" % (self._base_id, urllib.parse.quote(id_))
 
     def _header_to_id(self, header):
         """Convert a Content-ID header value to an id.
@@ -1321,7 +1315,7 @@ class BatchHttpRequest(object):
             raise BatchError("Invalid value for Content-ID: %s" % header)
         base, id_ = header[1:-1].split(" + ", 1)
 
-        return unquote(id_)
+        return urllib.parse.unquote(id_)
 
     def _serialize_request(self, request):
         """Convert an HttpRequest object into a string.
@@ -1333,8 +1327,8 @@ class BatchHttpRequest(object):
           The request as a string in application/http format.
         """
         # Construct status line
-        parsed = urlparse(request.uri)
-        request_line = urlunparse(
+        parsed = urllib.parse.urlparse(request.uri)
+        request_line = urllib.parse.urlunparse(
             ("", "", parsed.path, parsed.params, parsed.query, "")
         )
         status_line = request.method + " " + request_line + " HTTP/1.1\n"
@@ -1353,7 +1347,7 @@ class BatchHttpRequest(object):
         if "content-type" in headers:
             del headers["content-type"]
 
-        for key, value in six.iteritems(headers):
+        for key, value in headers.items():
             msg[key] = value
         msg["Host"] = parsed.netloc
         msg.set_unixfrom(None)
@@ -1363,7 +1357,7 @@ class BatchHttpRequest(object):
             msg["content-length"] = str(len(request.body))
 
         # Serialize the mime message.
-        fp = StringIO()
+        fp = io.StringIO()
         # maxheaderlen=0 means don't line wrap headers.
         g = Generator(fp, maxheaderlen=0)
         g.flatten(msg, unixfrom=False)
@@ -1488,7 +1482,7 @@ class BatchHttpRequest(object):
 
         # encode the body: note that we can't use `as_string`, because
         # it plays games with `From ` lines.
-        fp = StringIO()
+        fp = io.StringIO()
         g = Generator(fp, mangle_from_=False)
         g.flatten(message, unixfrom=False)
         body = fp.getvalue()
@@ -1509,8 +1503,7 @@ class BatchHttpRequest(object):
         header = "content-type: %s\r\n\r\n" % resp["content-type"]
         # PY3's FeedParser only accepts unicode. So we should decode content
         # here, and encode each payload again.
-        if six.PY3:
-            content = content.decode("utf-8")
+        content = content.decode("utf-8")
         for_parser = header + content
 
         parser = FeedParser()
@@ -1526,7 +1519,7 @@ class BatchHttpRequest(object):
             request_id = self._header_to_id(part["Content-ID"])
             response, content = self._deserialize_response(part.get_payload())
             # We encode content here to emulate normal http response.
-            if isinstance(content, six.text_type):
+            if isinstance(content, str):
                 content = content.encode("utf-8")
             self._responses[request_id] = (response, content)
 
@@ -1813,7 +1806,8 @@ class HttpMockSequence(object):
         # Remember the request so after the fact this mock can be examined
         self.request_sequence.append((uri, method, body, headers))
         resp, content = self._iterable.pop(0)
-        content = six.ensure_binary(content)
+        if isinstance(content, str):
+            content = content.encode("utf-8")
 
         if content == b"echo_request_headers":
             content = headers
@@ -1826,7 +1820,7 @@ class HttpMockSequence(object):
                 content = body
         elif content == b"echo_request_uri":
             content = uri
-        if isinstance(content, six.text_type):
+        if isinstance(content, str):
             content = content.encode("utf-8")
         return httplib2.Response(resp), content
 
